import java.awt.*;
import objectdraw.*;

/*
 * Chain Reaction:
 * 
 * On a mouse press, the user can place balls on the canvas;
 * On exiting the window, a simulation of a "chain reaction" begins:
 * the most recently drawn ball hits into the second most recently drawn,
 * which hits into the next ball, and so on.
 * The canvas is cleared when the mouse enters the window.
 *
 * Example from Williams College CS 134
 * by Andrea Danyluk, from March 2002.
 */

public class ChainReaction extends WindowController
{

    // x and y coordinates of the first ball drawn
    private static final int BALL_X = 300;
    private static final int BALL_Y = 100;

    // ball diameter
    private static final int SIZE = 10;

    // distance between balls
    private static final int DISP = 2*SIZE;

    // x coordinate of the next ball to be drawn
    private int ballX = BALL_X;

    // the list of all balls
    private BallList ballList;

    public void begin()
    {
        // list of balls is empty at first
        ballList = new BallList(null, null);
    }

    // draws a ball
    public void onMousePress(Location point)
    {
        ballList = new BallList(new FilledOval(ballX, BALL_Y, SIZE, SIZE, canvas), ballList);
        // update x coordinate for the next ball to be drawn
        ballX = ballX - DISP;
    }

    // cause the balls to begin hitting into each other in a "chain reaction"
    public void onMouseExit(Location point)
    {
        ballList.react();
    }

    // clears the canvas and empties the ball list
    public void onMouseEnter(Location point)
    {
        canvas.clear();
        ballList = new BallList(null, null);
        ballX = BALL_X;
    }

}